<?php
/**
* @author: Egor Smolyakov, 2012.
* @e-mail: mr.stelhammer@gmail.com
*/
defined('ROOT') or define('ROOT', $_SERVER['DOCUMENT_ROOT']);
require_once ROOT . '/system/init.php';
page_head($set['title_index'].'', 1);
if ($_GET['err'] == '10') {
echo '<div class="menu"><center>
<font size=3 color=#dd0000>
<b>Переход по рекламной ссылке был заблокирован.</b>
<p>
</font>
<font size=2 color=#dd0000>
Сервисом оплачиваются только естественные переходы.<br>
Не оплачивается скликивание, трафик из серфингов и буксов,<br>
клики через прокси, а также с временно заблокированных сайтов.
</font>
</center></div>';
}
if ($_GET['act'] == 'office' && $is_user) {
echo '
<div class="aut">';
if($user['admin']) {
echo '&raquo; <a href="'.HOST.'/admin/"><b><font color="orange">Админ - Панель</font></b></a><br />';
if (DB :: run() -> querySingle("SELECT COUNT(*) FROM `tickets` WHERE `open` = '1' AND `new_reply` = '2';") > 0) echo ' <span style="color: red">Админ нужно ответить!</span><br/>';
if (DB :: run() -> querySingle("SELECT COUNT(*) FROM `sites` WHERE `moderation` = '0' AND `active` != '2';") > 0) echo ' <span style="color: red">Админ нужно одобрить !</span><br/>';
if (DB :: run() -> querySingle("SELECT COUNT(*) FROM `users` WHERE `out_check` = '1';") > 0) echo ' <span style="color: red">Админ нужно вывести !</span><br/>';
}

echo '</div><div class=title>Привет, <b><FONT color=<"Firebrick">'.$user['login'].'</b></FONT><br /></div>
На балансе: <b>'.number_format($user['rub'],2).'</b> руб.';
if($user['out_all']) echo '<br />Выплачено: <b>'.number_format($user['out_all'],2).'</b> руб.';
if($set['min_out'] < $user['rub']) if($user['out_check'] == 0) echo '<br /><div class=menu>
<form action="'.HOST.'/out/check/" method=POST><input type=submit value="Вывести деньги"/><br/>
</form></div>'; else echo '<br /><b>Заявка на вывод средств подана, скоро ваши рубли будут у вас на кошельке !</b>';

echo '</div>
';

echo '<div class="title">Кабинет</div>
<div class="menu_j"><a href="'.HOST.'/sites/" class="top_menu_j"><img src="/assets/images/ind.png" alt="*"/><FONT color=<"Red">['.DB :: run() -> querySingle("SELECT COUNT(*) FROM `sites` WHERE `user_id` = '".$user['id']."' AND `active` = '1';").'/'.DB :: run() -> querySingle("SELECT COUNT(*) FROM `sites` WHERE `user_id` = '".$user['id']."';").']</FONT> Сайты</a></div>';

echo '
<div class="menu_j"><a href="'.HOST.'/stat/" class="top_menu_j"><img src="/assets/images/ind.png" alt="*"/> Статистика</a></div>';

echo '<div class="menu_j"><a href="'.HOST.'/oplata.html" class="top_menu_j"><img src="/assets/images/ind.png" alt="*"/><FONT color=<"Red">(info)</FONT> Выплата</a></div>';

//echo '<div class="menu_j"> <a href="'.HOST.'/forum/" class="top_menu_j"><img src="/assets/images/ind.png" alt="*"/>  Форум</a></a></div>
echo '<div class="menu_j"><a href="'.HOST.'/tickets/" class="top_menu_j"><img src="/assets/images/ind.png" alt="*"/> Тикет </a>';
if (DB :: run() -> querySingle("SELECT COUNT(*) FROM `tickets` WHERE `user_author` = '".$user['login']."' AND `new_reply` = '1';") > 0) echo ' <span style="color: red">Вам ответили!</span></div>';



echo '
<div class="menu_j"><a href="'.HOST.'/setting/" class="top_menu_j"><img src="/assets/images/ind.png" alt="*"/> Настройки</a></div>
</div>';

echo '
<div class="menu_j"><a href="'.HOST.'/logs/auth/" class="top_menu_j"><img src="/assets/images/ind.png" alt="*"/> История входов</a></div>
</div>';

echo '
<div class="menu_j"><a href="'.HOST.'/my/referals/" class="top_menu_j"><img src="/assets/images/ind.png" alt="*"/> Партнеры</a></div>
</div>';
} else {


$dat = DB :: run() -> queryFetch("SELECT `out_time` FROM `users` ORDER BY `out_time` DESC LIMIT 1;");
echo '<img src="/assets/images/galka.png" alt="*"/>Выкупаем трафик с ваших сайтов по высоким ценам! <a href="http://clik.online/cost/ "title="Цены за переходы"/><FONT color=<"Firebrick">400р. за 1000 переходов.</FONT></a><br /> <img src="/assets/images/galka.png" alt="*"/>Три формата реклымы на ваш выбор - Тизерная, Баннерная и Текстовая.<br /> <img src="/assets/images/galka.png" alt="*"/>С каждого активного реферала вы получаете <FONT color=<"Firebrick">50%</FONT> от его заработка.<br /> <img src="/assets/images/galka.png" alt="*"/>Выплата по запросу в течении 24 часов, минималка <FONT color=<"Firebrick">20р.</FONT><br />
<img src="/assets/images/galka.png" alt="*"/>Нет санкций от поисковиков.<br /> <img src="/linss1.png" alt="*"/><br /><img src="/assets/images/galka2.png" alt="*"/>  Перед началом работы прочитайте пожалуйста наши <a href="/page/rules/">Правила</a></div><br/>';


//echo '<div class="menu_j"><a href="/office/" class="top_menu_j"><span class="arrow"><img src="/assets/images/ind.png" alt="*"/> Перейти в личный кабинет</span></a></div>';

if(isset($_POST) and !empty($_POST['login']) and !empty($_POST['password']))
{
	$login = protect($_POST['login']);
	$password = protect($_POST['password']);
	
	$querycheck = DB :: run() -> query("SELECT * FROM `users` WHERE (`login`= '".$login."' OR `id` = '".$login."');");
    $user_auth = $querycheck -> fetch();
      
      if (!empty($user_auth)) {
        if (($login == $user_auth['login'] || $login == $user_auth['id']) && md5_hash($password) == $user_auth['password']) {
		if($user_auth['banned'] == 1) {
		echo '<div class="menu">Аккаунт заблокирован! Пояснение было выслано на e-mail указанный при регистрации.</div>';
		}else{
        setcookie('login', $user_auth['login'], time()+3600*24*365, '/');
		setcookie('password', $password, time()+3600*24*365, '/'); 
		DB :: run() -> query ("INSERT INTO `logs_auth` SET `ip` = '".$ip."', `browser` = '".$useragent."', `time` = '".TIME."', `user_login` = '".$user_auth['login']."'");
		redir (HOST);
		}
        } else {
		echo '<div class="menu">Вы ввели неправильные данные!</div>';
		}
} else {
		echo '<div class="menu">Вы ввели неправильные данные!</div>';
}
}

if (!$is_user) {
echo '<div class="menu_enter">
<form action="/" method="POST">
<input name="login" id="login" type="text" placeholder="Ваш логин" /><br />
<input name="password" id="password" type="password" placeholder="Ваш пароль" /><br />
<input name="submit" type="submit" value="Войти" />
</form>
</div>';
} else {
    echo "<div><p>Привет, <FONT color=<'Firebrick'>".$user["login"]."!</p></FONT><div class='menu_j'><a href='/office/' class='top_menu_j'><span class='arrow'><img src='/assets/images/ind.png' alt='*'/> Перейти в личный кабинет</span></a></div>
    <div class='menu_j'><a href='/exit//' class='top_menu_j'><span class='arrow'><img src='/assets/images/ind.png' alt='*'/> Скинуть авторизацию</span></a></div></div>";
}
echo "</div>";
echo '
<br /><div class="razd4">Последняя новость</div>';


 $querypost = DB :: run() -> query("SELECT * FROM `news` ORDER BY `id` DESC LIMIT 1;");
 $total = DB :: run() -> querySingle("SELECT count(*) FROM `news`;");
 if ($total > 0) {
 while ($news = $querypost -> fetch()) {

 echo '<div class="title"><b>Выплаты</b> ('.view_date($news['time']).')<br />';
echo ''.nl2br($news['text_news']).'<br /></div>';
 }
} else {
echo '<div class="menu">Новостей нет.</div>';
}


echo '<div class="razd4">Меню</div><div class="menu">';

if (!$is_user) echo '<div class="menu_j"><a href="'.HOST.'/reg/" class="top_menu_j"><span class="arrow"><img src="/assets/images/ind.png" alt="*"/> Регистрация</a>';
$last_news = DB :: run() -> queryFetch("SELECT `time` FROM `news` ORDER BY `id` DESC LIMIT 1;");
echo '<div class="menu_j"><a href="'.HOST.'/news/" class="top_menu_j"><span class="arrow"><img src="/assets/images/ind.png" alt="*"/> Новости </a>';
if (!$is_user) echo '<div class="menu_j"><a href="'.HOST.'/recovery/" class="top_menu_j"><span class="arrow"><img src="/assets/images/ind.png" alt="*"/> Забыли пароль?</a>';
echo '<div class="menu_j"><a href="'.HOST.'/cost/" class="top_menu_j"><span class="arrow"><img src="/assets/images/ind.png" alt="*"/> Расценки </a>
<div class="menu_j"><a href="'.HOST.'/page/rules/" class="top_menu_j"><span class="arrow"><img src="/assets/images/ind.png" alt="*"/> Правила</a> 
<div class="menu_j"><a href="'.HOST.'/page/faq/" class="top_menu_j"><span class="arrow"><img src="/assets/images/ind.png" alt="*"/> FAQ</a></div>
';
$tcount = DB :: run() -> queryFetch("SELECT * FROM `counter` WHERE `type` = 'teasers';");

$bcount = DB :: run() -> queryFetch("SELECT * FROM `counter` WHERE `type` = 'banners';");

$acount = DB :: run() -> queryFetch("SELECT * FROM `counter` WHERE `type` = 'ads';");
$ccount = DB :: run() -> queryFetch("SELECT * FROM `counter` WHERE `type` = 'ClickUnder';");
/*echo "
  <table width='100%'>
   <tr align='center'><td class='title' colspan='4'><b>Общая статистика</b></td></tr>
   <tr align='center'>
   <td class='aut'><b>Показатель</b></td>
   <td class='aut'><b>Показов:</b></td><td class='aut'><b>Переходов:</b></td>
   </tr>
   <tr>
   <td class='menu'><b>По тизерам</b></td><td class='menu'>".$tcount['pokaz']."</td><td class='menu'>".$tcount['click']."</td>
 </tr><tr>  <td class='menu'><b>По баннерам</b></td>
 <td class='menu'>".$bcount['pokaz']."</td><td class='menu'>".$bcount['click']."</td></tr><tr>
    <td class='menu'><b>По текс. рек.</b></td>
  <td class='menu'>".$acount['pokaz']."</td>
   <td class='menu'>".$acount['click']."</td>
   <tr>
   <td class='menu'><b>По ClickUnder</b></td>
  <td class='menu'>-</td>
   <td class='menu'>".$ccount['click']."</td>
   <tr>
   
   
   
   </tr>
   </table>";
 
   echo "
  <table width='100%'>
   <tr align='center'><td class='title' colspan='4'><b>Статистика за сегодня</b></td></tr>
   <tr align='center'>
   <td class='aut'><b>Показатель</b></td>
   <td class='aut'><b>По тизерам</b></td>
   <td class='aut'><b>По баннерам</b></td>
   <td class='aut'><b>По текс. рек.</b></td>
   </tr>
   <tr>
   <td class='menu'><b>Показов:</b></td>
   <td class='menu'>".$tcount['pokaz']."</td>
   <td class='menu'>".$bcount['pokaz']."</td>
   <td class='menu'>".$acount['pokaz']."</td>
   <tr>
   <td class='menu'><b>Переходов:</b></td>
   <td class='menu'>".$tcount['click']."</td>
   <td class='menu'>".$bcount['click']."</td>
   <td class='menu'>".$acount['click']."</td>
   
   </tr>
   </table>";
 
   <tr>
   <td class='menu'><b>Заработано:</b></td>
   <td class='menu'>".$tcount['rub']."</td>
   <td class='menu'>".$bcount['rub']."</td>
   <td class='menu'>".$acount['rub']."</td>
   </tr>
   echo "<table width='100%'>
   <tr align='center'><td class='title' colspan='4'><b>По баннерам</b></td></tr>
   <tr align='center'>
   <td class='aut'><b>Показатель</b></td>
   <td class='aut'><b>Сегодня</b></td>
   <td class='aut'><b>Вчера</b></td>
   </tr>
      <tr>
   <td class='menu'><b>Показов:</b></td>
   <td class='menu'>".$bcount['pokaz']."</td>
   <td class='menu'>".$bcount['pokaz_yday']."</td>
   </tr>
   <tr>
   <td class='menu'><b>Переходов:</b></td>
   <td class='menu'>".$bcount['click']."</td>
   <td class='menu'>".$bcount['click_yday']."</td>
   </tr>
   <tr>
   <td class='menu'><b>Заработано:</b></td>
   <td class='menu'>".$bcount['rub']."</td>
   <td class='menu'>".$bcount['rub_yday']."</td>
   </tr>
  </table><table width='100%'>
   <tr align='center'><td class='title' colspan='4'><b>По текстовым рекламам</b></td></tr>
   <tr align='center'>
   <td class='aut'><b>Показатель</b></td>
   <td class='aut'><b>Сегодня</b></td>
   <td class='aut'><b>Вчера</b></td>
   </tr>
   <tr>
   <td class='menu'><b>Показов:</b></td>
   <td class='menu'>".$acount['pokaz']."</td>
   <td class='menu'>".$acount['pokaz_yday']."</td>
   </tr>
   <tr>
   <td class='menu'><b>Переходов:</b></td>
   <td class='menu'>".$acount['click']."</td>
   <td class='menu'>".$acount['click_yday']."</td>
   </tr>
   <tr>
   <td class='menu'><b>Заработано:</b></td>
   <td class='menu'>".$acount['rub']."</td>
   <td class='menu'>".$acount['rub_yday']."</td>
   </tr>
   </table>";
   */
/*echo '
<div class="aut">Последняя новость</div>';


 $querypost = DB :: run() -> query("SELECT * FROM `news` ORDER BY `id` DESC LIMIT 1;");
 $total = DB :: run() -> querySingle("SELECT count(*) FROM `news`;");
 if ($total > 0) {
 while ($news = $querypost -> fetch()) {

 echo '<div class="title"><b>'.$news['title'].'</b> ('.view_date($news['time']).')<br />';
echo ''.nl2br($news['text_news']).'<br /></div>';
 }
} else {
echo '<div class="menu">Новостей нет.</div>';
}


echo '<div class="title">Меню</div><div class="menu">';

if (!$is_user) echo '[<a href="'.HOST.'/reg/"> Регистрация</a>] <br />';
$last_news = DB :: run() -> queryFetch("SELECT `time` FROM `news` ORDER BY `id` DESC LIMIT 1;");
echo '[<a href="'.HOST.'/news/"> Новости </a>]'; if($last_news > 0) echo ' ['.view_date($last_news['time']).']';
echo '<br />';
if (!$is_user) echo '[<a href="'.HOST.'/recovery/"> Забыли пароль?</a>]<br />';
echo '[<a href="'.HOST.'/cost/"> Расценки ['.DB :: run() -> querySingle("SELECT COUNT(*) FROM `operators`;").' операторов]</a><br />
[<a href="'.HOST.'/page/rules/"> Правила</a>] <br />
[<a href="'.HOST.'/page/faq/"> FAQ</a>] <br />
[<a href="'.HOST.'/rating/partners/"> Рейтинг партнеров</a>]<br />
[<a href="'.HOST.'/rating/referals/"> Рейтинг рефералов</a>]<br /></div>
<div class="title">Реклама</div><div class="menu">
<script type="text/javascript" src="http://clik.online/banners/7.js"></script><br /><script type="text/javascript" src="http://clik.online/ads/7.js"></script>
</div>
';
/*
echo '<div class="title">Пример:</div><div class="menu">Тизерная реклама</div><div class="menu"><script type="text/javascript" src="http://clik.online/teasers/1.js"></script></div>
<div class="menu">Баннер</div><div class="menu"><script type="text/javascript" src="http://clik.online/banners/1.js"></script></div>
<div class="menu">Текстовая реклама</div><div class="menu"><script type="text/javascript" src="http://clik.online/ads.php?id=1"></script></div>';
*/
}
page_foot(); 

?>